The googledoc Module
====================


|Pypi| |PypiDownloads| |GithubActions| |Codecov|


This module aims to provide a simple means to parse information out of
google-style docstrings.

We may consider developing this into a proper sphinx extension as well, similar
to numpydoc, and potentially as an alternative to neopoleon.


Related Packages:
* https://github.com/numpy/numpydoc
* https://github.com/sphinx-contrib/napoleon



.. |Pypi| image:: https://img.shields.io/pypi/v/googledoc.svg
    :target: https://pypi.python.org/pypi/googledoc

.. |PypiDownloads| image:: https://img.shields.io/pypi/dm/googledoc.svg
    :target: https://pypistats.org/packages/googledoc

.. |GithubActions| image:: https://github.com/Erotemic/googledoc/actions/workflows/tests.yml/badge.svg?branch=main
    :target: https://github.com/Erotemic/googledoc/actions?query=branch%3Amain

.. |Codecov| image:: https://codecov.io/github/Erotemic/googledoc/badge.svg?branch=main&service=github
    :target: https://codecov.io/github/Erotemic/googledoc?branch=main
